==> kubernetes-model-apiextensions-4.12.0-sources.jar: io/fabric8/kubernetes/api/model/apiextensions/v1beta1/CustomResourceSubresourceScaleBuilder.java <==
package io.fabric8.kubernetes.api.model.apiextensions.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class CustomResourceSubresourceScaleBuilder extends io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceSubresourceScaleFluentImpl<io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceSubresourceScaleBuilder> implements VisitableBuilder<io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceSubresourceScale,io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceSubresourceScaleBuilder> {

    io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceSubresourceScaleFluent<?> fluent;
    Boolean validationEnabled;

    public CustomResourceSubresourceScaleBuilder() { 
        this(true);
    }


    public CustomResourceSubresourceScaleBuilder(Boolean validationEnabled) { 
        this(new CustomResourceSubresourceScale(), validationEnabled);
    }


    public CustomResourceSubresourceScaleBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceSubresourceScaleFluent<?> fluent) { 
        this(fluent, true);
    }


    public CustomResourceSubresourceScaleBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceSubresourceScaleFluent<?> fluent,Boolean validationEnabled) { 
        this(fluent, new CustomResourceSubresourceScale(), validationEnabled);
    }


    public CustomResourceSubresourceScaleBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceSubresourceScaleFluent<?> fluent,io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceSubresourceScale instance) { 
        this(fluent, instance, true);
    }


    public CustomResourceSubresourceScaleBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceSubresourceScaleFluent<?> fluent,io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceSubresourceScale instance,Boolean validationEnabled) { 
        this.fluent = fluent; 
        fluent.withLabelSelectorPath(instance.getLabelSelectorPath()); 
        fluent.withSpecReplicasPath(instance.getSpecReplicasPath()); 
        fluent.withStatusReplicasPath(instance.getStatusReplicasPath()); 
        this.validationEnabled = validationEnabled; 
    }


    public CustomResourceSubresourceScaleBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceSubresourceScale instance) { 
        this(instance,true);
    }


    public CustomResourceSubresourceScaleBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceSubresourceScale instance,Boolean validationEnabled) { 
        this.fluent = this; 
        this.withLabelSelectorPath(instance.getLabelSelectorPath()); 
        this.withSpecReplicasPath(instance.getSpecReplicasPath()); 
        this.withStatusReplicasPath(instance.getStatusReplicasPath()); 
        this.validationEnabled = validationEnabled; 
    }


    public io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceSubresourceScale build() {
        CustomResourceSubresourceScale buildable = new CustomResourceSubresourceScale(fluent.getLabelSelectorPath(),fluent.getSpecReplicasPath(),fluent.getStatusReplicasPath());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        CustomResourceSubresourceScaleBuilder that = (CustomResourceSubresourceScaleBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}

==> kubernetes-model-apiextensions-5.4.2-sources.jar: io/fabric8/kubernetes/api/model/apiextensions/v1beta1/CustomResourceSubresourceScaleBuilder.java <==
package io.fabric8.kubernetes.api.model.apiextensions.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class CustomResourceSubresourceScaleBuilder extends io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceSubresourceScaleFluentImpl<io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceSubresourceScaleBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceSubresourceScale,io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceSubresourceScaleBuilder> {

    io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceSubresourceScaleFluent<?> fluent;
    java.lang.Boolean validationEnabled;

    public CustomResourceSubresourceScaleBuilder() {
        this(true);
    }

    public CustomResourceSubresourceScaleBuilder(java.lang.Boolean validationEnabled) {
        this(new CustomResourceSubresourceScale(), validationEnabled);
    }

    public CustomResourceSubresourceScaleBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceSubresourceScaleFluent<?> fluent) {
        this(fluent, true);
    }

    public CustomResourceSubresourceScaleBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceSubresourceScaleFluent<?> fluent,java.lang.Boolean validationEnabled) {
        this(fluent, new CustomResourceSubresourceScale(), validationEnabled);
    }

    public CustomResourceSubresourceScaleBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceSubresourceScaleFluent<?> fluent,io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceSubresourceScale instance) {
        this(fluent, instance, true);
    }

    public CustomResourceSubresourceScaleBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceSubresourceScaleFluent<?> fluent,io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceSubresourceScale instance,java.lang.Boolean validationEnabled) {
        this.fluent = fluent; 
        fluent.withLabelSelectorPath(instance.getLabelSelectorPath()); 
        fluent.withSpecReplicasPath(instance.getSpecReplicasPath()); 
        fluent.withStatusReplicasPath(instance.getStatusReplicasPath()); 
        this.validationEnabled = validationEnabled; 
    }

    public CustomResourceSubresourceScaleBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceSubresourceScale instance) {
        this(instance,true);
    }

    public CustomResourceSubresourceScaleBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceSubresourceScale instance,java.lang.Boolean validationEnabled) {
        this.fluent = this; 
        this.withLabelSelectorPath(instance.getLabelSelectorPath()); 
        this.withSpecReplicasPath(instance.getSpecReplicasPath()); 
        this.withStatusReplicasPath(instance.getStatusReplicasPath()); 
        this.validationEnabled = validationEnabled; 
    }

    public io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceSubresourceScale build() {
        CustomResourceSubresourceScale buildable = new CustomResourceSubresourceScale(fluent.getLabelSelectorPath(),fluent.getSpecReplicasPath(),fluent.getStatusReplicasPath());
        return buildable;
    }

    public boolean equals(java.lang.Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        CustomResourceSubresourceScaleBuilder that = (CustomResourceSubresourceScaleBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}
